You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@dubbo.apache.org by al...@apache.org on 2023/11/11 12:35:52 UTC
(dubbo-website) 01/01: Merge branch 'master' into history/next
This is an automated email from the ASF dual-hosted git repository.
albumenj pushed a commit to branch history/next
in repository https://gitbox.apache.org/repos/asf/dubbo-website.git
commit 90b20219db0c4a2af4187e36e712c9869e23381d
Merge: 4178b55baed ef617693f4b
Author: Albumen Kevin <jh...@gmail.com>
AuthorDate: Sat Nov 11 20:35:22 2023 +0800
Merge branch 'master' into history/next
.htmltest.yml | 1 +
content/en/blog/news/intellij-idea-dubbo-plugin.md | 56 +++++
content/en/overview/tasks/extensibility/_index.md | 100 ++++++++
content/en/overview/tasks/extensibility/filter.md | 11 +
.../en/overview/tasks/extensibility/protocol.md | 278 +++++++++++++++++++++
.../en/overview/tasks/extensibility/registry.md | 10 +
content/en/overview/tasks/extensibility/router.md | 175 +++++++++++++
.../zh-cn/blog/integration/dubbo-spring-cloud.md | 2 +-
.../triple-to-connect-frontend-and-backend.md | 4 +-
.../blog/news/apachecon2023/usecase-zhengcaiyun.md | 4 +-
.../zh-cn/blog/news/intellij-idea-dubbo-plugin.md | 51 ++++
.../overview/tasks/observability/tracing/zipkin.md | 2 +-
static/imgs/blog/2023/10/plugin/img.png | Bin 0 -> 190613 bytes
static/imgs/blog/2023/10/plugin/img_1.png | Bin 0 -> 573111 bytes
static/imgs/blog/2023/10/plugin/img_2.png | Bin 0 -> 539240 bytes
static/imgs/blog/2023/10/plugin/img_3.png | Bin 0 -> 1307781 bytes
static/imgs/blog/2023/10/plugin/img_4.png | Bin 0 -> 2193563 bytes
static/imgs/blog/2023/10/plugin/img_5.png | Bin 0 -> 718798 bytes
static/imgs/blog/2023/10/plugin/img_6.png | Bin 0 -> 158789 bytes
.../quickstart/idl-directly-curl-remote.jpg | Bin 0 -> 540451 bytes
.../quickstart/idl-directly-curl-terminal.jpg | Bin 0 -> 450922 bytes
.../idl-directly-github-codespace-public.png | Bin 0 -> 1975344 bytes
.../java-sdk/quickstart/idl-directly-sdk.jpg | Bin 0 -> 508946 bytes
.../quickstart/idl-directly-server-started.jpg | Bin 0 -> 965009 bytes
24 files changed, 688 insertions(+), 6 deletions(-)